/**
 * Storage工具类
 */
// 存储前缀
import { storage_prefix } from '../config'
// url验证
import { tools_uri } from '../tools'
class Storage {
  constructor(type) {
    if (type === 'local') {
      this.store = window.localStorage
    } else if (type === 'session') {
      this.store = window.sessionStorage
    }
    this.prefix = storage_prefix
  }

  set(key, value) {
    try {
      value = JSON.stringify(value)
    } catch (e) {
      value = {}
    }
    this.store.setItem(
      tools_uri.encode(this.prefix + key),
      tools_uri.encode(value)
    )

    return this
  }

  get(key) {
    if (!key) {
      throw new Error('没有找到key。')
    }
    if (typeof key === 'object') {
      throw new Error('key不能是一个对象。')
    }

    let value = this.store.getItem(tools_uri.encode(this.prefix + key))
    if (value === null) {
      return
    }

    try {
      value = JSON.parse(tools_uri.decode(value))
    } catch (e) {
      value
    }
    return value
  }

  remove(key) {
    this.store.removeItem(tools_uri.encode(this.prefix + key))
    return this
  }
}

export const localStorage = new Storage('local')
export const sessionStorage = new Storage('session')
