import Vue from 'vue'
import Router from 'vue-router'
// const _import = require('./_import_' + process.env.NODE_ENV)
// in development-env not use lazy-loading, because lazy-loading too many pages will cause webpack hot update too slow. so only in production use lazy-loading;
// detail: https://panjiachen.github.io/vue-element-admin-site/#/lazy-loading

Vue.use(Router)

/* Layout */
import Layout from '../views/layout/Layout'

/**
 * hidden: true                   if `hidden:true` will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu, whatever its child routes length
 *                                if not set alwaysShow, only more than one route under the children
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noredirect           if `redirect:noredirect` will no redirct in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    title: 'title'               the name show in submenu and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar,
  }
 **/
export const constantRouterMap = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },
  { path: '/404', component: () => import('@/views/404'), hidden: true },
  {
    path: '/',
    component: Layout,
    redirect: '/userList',
    children: [
      {
        path: '/userList',
        component: () => import('@/views/user/index'),
        name: 'userList',
        meta: { title: '用户管理', noCache: false }
      }
    ]
  },
  {
    path: '',
    component: Layout,
    children: [
      {
        path: '/pianoList',
        component: () => import('@/views/piano/index'),
        name: 'pianoList',
        meta: { title: '商家管理', noCache: false }
      },
      {
        path: '/pianoEdit',
        component: () => import('@/views/piano/pianoEdit'),
        name: 'pianoEdit',
        meta: { title: '商家编辑', noCache: false },
        hidden: true
      }
    ]
  },
  {
    path: '',
    component: Layout,
    children: [
      {
        path: '/userCost',
        component: () => import('@/views/userCost/index'),
        name: 'userCost',
        meta: { title: '消费记录', noCache: false }
      }
    ]
  },
  {
    path: '',
    component: Layout,
    children: [
      {
        path: '/bannerList',
        component: () => import('@/views/system/banner/index'),
        name: 'bannerList',
        meta: { title: '广告图管理', noCache: false }
      },
      {
        path: '/bannerEdit',
        component: () => import('@/views/system/banner/bannerEdit'),
        name: 'bannerEdit',
        meta: { title: '广告图编辑', noCache: false },
        hidden: true
      }
    ]
  },
  {
    path: '',
    component: Layout,
    children: [
      {
        path: '/courseList',
        component: () => import('@/views/course/index'),
        name: 'courseList',
        meta: { title: '在线课程管理', noCache: false }
      },
      {
        path: '/courseEdit',
        component: () => import('@/views/course/courseEdit'),
        name: 'courseEdit',
        meta: { title: '在线课程编辑', noCache: false },
        hidden: true
      }
    ]
  },
  {
    path: '',
    component: Layout,
    children: [
      {
        path: '/bargainList',
        component: () => import('@/views/bargain/index'),
        name: 'bargainList',
        meta: { title: '砍价活动管理', noCache: false }
      },
      {
        path: '/bargainEdit',
        component: () => import('@/views/bargain/bargainEdit'),
        name: 'bargainEdit',
        meta: { title: '砍价活动编辑', noCache: false },
        hidden: true
      }
    ]
  },
  {
    path: '',
    component: Layout,
    children: [
      {
        path: '/code',
        component: () => import('@/views/code/index'),
        name: 'code',
        meta: { title: '二维码管理', noCache: false }
      },
      
    ]
  },
  {
    path: '',
    component: Layout,
    children: [
      {
        path: '/pianoSubmit',
        component: () => import('@/views/pianoList/index'),
        name: 'pianoSubmit',
        meta: { title: '商家申请', noCache: false }
      },
      
    ]
  },
  { path: '*', redirect: '/404', hidden: true }
]

export default new Router({
  // mode: 'history', //后端支持可开
  scrollBehavior: () => ({ x: 0 }),
  routes: constantRouterMap
})

export const asyncRouterMap = [{ path: '*', redirect: '/404', hidden: true }]
